@@ -120,7 +120,7 @@ libwww-perl.5808.
 
 =head1 SOURCE CODE REPOSITORY
 
-L<http://www.cantrell.org.uk/cgit/cgit.cgi/perlmodules/>
+L<git://github.com/DrHyde/perl-modules-CPAN-FindDependencies.git>
 
 =head1 SEE ALSO
 
